@@ -137,7 +137,7 @@ class GridPlot:
                                 alpha": 1,
                                 }
             The default is {}. 
-            If set to None, no histograms will be added to diagonal of the grid plot. 
+            If set to None, no kdeplots will be added to the grid plot. 
         lineplot_kws
             optional dictionary of keyword arguments to be passed to an instance of 
             ParaMonte's LinePlot class for making colored line plots of the requested 
@@ -167,15 +167,17 @@ class GridPlot:
         kdecorner
             optional string representing the corner (upper/lower triangle) of the grid 
             plot where the kdeplots will be added. 
-            Possible values are: "upper", "lower", None. 
-            The default is "lower". 
-            If set to None, the corner will be automatically determined. 
+            Possible values are: "upper", "lower", "auto", None. 
+            The default is "auto", which is the lower or any empty corner. 
+            If set to "auto", the corner will be automatically determined. 
+            If set to None, no kdeplots will be added to the grid plot. 
         lscorner
             optional string representing the corner (upper/lower triangle) of the grid 
             plot where the line/scatter plots will be added. 
-            Possible values are: "upper", "lower", None. 
-            The default is "upper".
-            If set to None, the corner will be automatically determined. 
+            Possible values are: "upper", "lower", "auto", None. 
+            The default is "auto", which is the upper or any empty corner. 
+            If set to "auto", the corner will be automatically determined. 
+            If set to None, no scatter or line plots will be added to the grid plot. 
 
     Attributes
     ----------
@@ -223,8 +225,8 @@ class GridPlot:
                 , scatterplot_kws   : _tp.Optional[_tp.Dict] = ()
                 , colorbar_kws      : _tp.Optional[_tp.Dict] = ()
                 , outputFile        : _tp.Optional[str] = None
-                , kdecorner         : _tp.Optional[str] = None
-                , lscorner          : _tp.Optional[str] = None
+                , kdecorner         : _tp.Optional[str] = "auto"
+                , lscorner          : _tp.Optional[str] = "auto"
                 , _methodName       : _tp.Optional[str] = ""
                 ):
 
@@ -249,7 +251,6 @@ class GridPlot:
         self._isdryrun = True
         self.plot()
         self._isdryrun = False
-
     ################################################################################################################################
 
     def __call__( self
@@ -310,38 +311,53 @@ class GridPlot:
         scatterplotEnabled = self.scatterplot_kws is not None
         lineplotEnabled = self.lineplot_kws is not None
         distplotEnabled = self.distplot_kws is not None
-        kdeplotEnabled = self.kdeplot_kws is not None
-        lsplotEnabled = scatterplotEnabled or lineplotEnabled
+        kdeplotEnabled = (self.kdeplot_kws is not None) and (self.kdecorner is not None)
+        lsplotEnabled = (scatterplotEnabled or lineplotEnabled) and (self.lscorner is not None)
 
         if self.set_kws==(): self.set_kws={}
 
         kdeUpperEnabled = False
         kdeLowerEnabled = False
         if kdeplotEnabled:
-            if self.kdecorner is None:
+            if self.kdecorner=="auto":
                 kdeLowerEnabled = True
             elif isinstance(self.kdecorner,str):
                 if "upper" in self.kdecorner: kdeUpperEnabled = True
                 if "lower" in self.kdecorner: kdeLowerEnabled = True
             else:
-                raise Exception ( "The input argument 'kdecorner' must be either 'lower', 'upper' or\n"
-                                + "a concatanation of both, or otherwise None." )
+                raise Exception ( "The input argument 'kdecorner' must be either,\n\n"
+                                + "    'upper', 'lower', 'upper-lower', 'auto',\n\n"
+                                + "or otherwise None." )
 
         lsUpperEnabled = False
         lsLowerEnabled = False
-        if scatterplotEnabled or lineplotEnabled:
-            if self.lscorner is None:
+        if lsplotEnabled:
+            if self.lscorner=="auto":
                 lsUpperEnabled = not kdeUpperEnabled
                 lsLowerEnabled = not kdeLowerEnabled
+                lsplotEnabled = lsLowerEnabled or lsUpperEnabled
             elif isinstance(self.lscorner,str):
                 if "upper" in self.lscorner: lsUpperEnabled = True
-                if "lower" in self.lscorner: lsLowerEnabled = True
+                if "lower" in self.lscorner: 
+                    lsLowerEnabled = True
+                    if self.kdecorner=="auto":
+                        kdeUpperEnabled = not lsUpperEnabled
+                        kdeLowerEnabled = not lsLowerEnabled
+                        kdeplotEnabled = kdeLowerEnabled or kdeUpperEnabled
             else:
-                raise Exception ( "The input argument 'lscorner' must be either 'lower', 'upper' or\n"
-                                + "a concatanation of both, or otherwise None." )
+                raise Exception ( "The input argument 'lscorner' must be either,\n\n"
+                                + "    'upper', 'lower', 'upper-lower', 'auto',\n\n"
+                                + "or otherwise None." )
+        elif kdeplotEnabled:
+            if self.kdecorner=="auto":
+                kdeUpperEnabled = True
+                kdeLowerEnabled = True
+            
+
 
         if self.kdeplot_kws==(): self.kdeplot_kws={}
         if isinstance(self.kdeplot_kws,dict):
+            #self.kdeplot_kws["cbar"]=True if lsplotEnabled==False else False
             self.kdeplot_kws["cbar"] = False
             if "cmap" not in self.kdeplot_kws.keys():           self.kdeplot_kws["cmap"] = "Blues"
             if "alpha" not in self.kdeplot_kws.keys():          self.kdeplot_kws["alpha"] = 1
@@ -494,10 +510,10 @@ class GridPlot:
         nkdeplotStr = str( (kdeUpperEnabled+kdeLowerEnabled) * nrow * (nrow-1) // 2 )
 
         self.currentFig.targetList      = [ [ [] for j in range(nrow) ] for i in range(nrow) ]
-        self.currentFig.kdeplotList     = [ [ [] for j in range(nrow) ] for i in range(nrow) ]
+       #self.currentFig.kdeplotList     = [ [ [] for j in range(nrow) ] for i in range(nrow) ]
         self.currentFig.lineplotList    = [ [ [] for j in range(nrow) ] for i in range(nrow) ]
         self.currentFig.scatterplotList = [ [ [] for j in range(nrow) ] for i in range(nrow) ]
-        self.currentFig.distplotList    = [ [] for i in range(nrow) ]
+       #self.currentFig.distplotList    = [ [] for i in range(nrow) ]
 
         #####################################
         #### add distplots as needed
@@ -621,6 +637,7 @@ class GridPlot:
         # set the ticks and labels
 
         nrowMinusOne = nrow - 1
+        from matplotlib.pyplot import setp
         for irow, row in enumerate(self.currentFig.pairgrid.axes[:]):
             for icol, ax in enumerate(row):
                 if self._lowerEnabled:
@@ -629,12 +646,30 @@ class GridPlot:
                     if irow < nrowMinusOne:
                         ax.set_xlabel("")
                 elif self._upperEnabled:
-                    if icol>irow:
+                    if (not kdeplotEnabled):
+                        if icol != irow:
+                            ax.set_ylabel("")
+                            ax.set_xlabel("")
+                        if icol == irow:
+                            ax.set_xlabel(colnames[irow])
+                            ax.set_ylabel(colnames[icol])
+                            ax.xaxis.set_tick_params(which="both", labelbottom=True)
+                            ax.yaxis.set_tick_params(which="both", labelbottom=True)
+                    elif icol > irow:
                         ax.set_ylabel("")
-                        ax.set_xlabel("")
+                        ax.set_xlabel("")                
+
+        import matplotlib.pyplot as _plt
+        _plt.subplots_adjust(hspace=0.15, wspace=0.15)
 
         # add colorbar
 
+        self._addcbar()
+
+    ################################################################################################################################
+
+    def _addcbar(self):
+
         mappable = None
         for scatterplotrow, lineplotrow in zip( self.currentFig.scatterplotList[:], self.currentFig.lineplotList[:] ):
             for scatterplot, lineplot in zip(scatterplotrow, lineplotrow):
@@ -644,32 +679,16 @@ class GridPlot:
                         cbarLabel = scatterplot.ccolumns
                         if len(cbarLabel)==0: cbarLabel = "Count from the Series Start"
                         break
-                elif lineplot != []:
+                if lineplot != []:
+                    if mappable is None and lineplot.ccolumns is not None:
                         mappable = lineplot.currentFig.lineCollection
                         cbarLabel = lineplot.ccolumns
                         if len(cbarLabel)==0: cbarLabel = "Count from the Series Start"
                         break
 
-#        sccolumnsEnabled = False
-#        if "ccolumns" in self.scatterplot_kws.keys():
-#            self.scatterplot_kws["ccolumns"] is not None: sccolumnsEnabled = True
-#        if scatterplotEnabled and self.scatterplot_kws["ccolumns"] is not None:
-#            if self.currentFig.scatterplotList[0][1] != []:
-#                mappable = self.currentFig.scatterplotList[0][1].currentFig.scatter 
-#            else:
-#                mappable = self.currentFig.scatterplotList[1][0].currentFig.scatter
-#            cbarLabel = self.scatterplot_kws["ccolumns"]
-#        elif lineplotEnabled and self.lineplot_kws["ccolumns"] is not None:
-#            if self.currentFig.lineplotList[0][1] != []:
-#                mappable = self.currentFig.lineplotList[0][1].currentFig.lineCollection 
-#            else:
-#                mappable = self.currentFig.lineplotList[1][0].currentFig.lineCollection
-#            cbarLabel = self.lineplot_kws["ccolumns"]
-#        #elif kdeplotEnabled and self.kdeplot_kws is not None:
-
         if mappable is not None:
-            self.currentFig.figure.colorbar = self.currentFig.figure.colorbar(mappable=mappable,ax=self.currentFig.pairgrid.axes)
-            self.currentFig.figure.colorbar.set_label(cbarLabel)
+            self.currentFig.figure.cbar = self.currentFig.figure.colorbar(mappable=mappable,ax=self.currentFig.pairgrid.axes)
+            self.currentFig.figure.cbar.set_label(cbarLabel)
             self.currentFig.figure.set_figwidth(self.currentFig.figure.get_figwidth()*1.3333)
 
     ################################################################################################################################
@@ -682,21 +701,35 @@ class GridPlot:
         ----------
             part
                 a string with the following possible values:
-                    - "lower": hides the lower triangle of the grid plot.
-                    - "upper": hides the lower triangle of the grid plot.
-                    - "diag" : hides the diagonal of the grid plot.
-                    - "all"  : hides all grid plots.
-
+                    - "lower"   : hides the lower triangle of the grid plot.
+                    - "upper"   : hides the upper triangle of the grid plot.
+                    - "diag"    : hides the diagonal of the grid plot.
+                    - "all"     : hides all grid plots and the colorbar.
+                    - "cbar"    : hides the colorbar of the grid plot.
+                    the string can also be a mix of the above keywords, 
+                    separated by the + sign or some other delimiter. 
+                    For example, "lower+upper+cbar"
         Returns
         -------
             None.
 
         """
 
-        allhidden = part=="all"
-        if allhidden or part=="upper": self.currentFig.pairgrid.map_upper(hide_current_axis)
-        if allhidden or part=="lower": self.currentFig.pairgrid.map_lower(hide_current_axis)
-        if allhidden or part=="diag" : self.currentFig.pairgrid.map_diag(hide_current_axis)
+        allhidden = "all" in part
+        if allhidden or ("upper" in part): self.currentFig.pairgrid.map_upper(hide_current_axis)    
+        if allhidden or ("lower" in part):
+            self.currentFig.pairgrid.map_lower(hide_current_axis)
+            colnames = dfutils.getColNamesIndex(self._dfref().columns,self.columns)[0]
+            if not allhidden:
+                for i in range(len(colnames)):
+                    ax=self.currentFig.pairgrid.axes[:][i][i]
+                    ax.set_xlabel(colnames[i])
+                    ax.set_ylabel(colnames[i])
+                    ax.xaxis.set_tick_params(which="both", labelbottom=True)
+                    ax.yaxis.set_tick_params(which="both", labelbottom=True)
+        if allhidden or ("diag" in part): self.currentFig.pairgrid.map_diag(hide_current_axis)
+        if allhidden or ("cbar" in part): self.currentFig.figure.cbar.remove()
+        #self.currentFig.figure.set_figwidth(self.currentFig.figure.get_figwidth()*1.3333)
 
     ################################################################################################################################
 
@@ -708,10 +741,14 @@ class GridPlot:
         ----------
             part
                 a string with the following possible values:
-                    - "lower": shows the lower triangle of the grid plot.
-                    - "upper": shows the lower triangle of the grid plot.
-                    - "diag" : shows the diagonal of the grid plot.
-                    - "all"  : shows all grid plots.
+                    - "lower"   : shows the lower triangle of the grid plot.
+                    - "upper"   : shows the lower triangle of the grid plot.
+                    - "diag"    : shows the diagonal of the grid plot.
+                    - "all"     : shows all grid plots.
+                    - "cbar"    : shows the colorbar of the grid plot.
+                    the string can also be a mix of the above keywords, 
+                    separated by the + sign or some other delimiter. 
+                    For example, "lower+upper+cbar"
 
         Returns
         -------
@@ -719,10 +756,27 @@ class GridPlot:
 
         """
 
-        allshown = part=="all"
-        if allshown or part=="upper": self.currentFig.pairgrid.map_upper(show_current_axis)
-        if allshown or part=="lower": self.currentFig.pairgrid.map_lower(show_current_axis)
-        if allshown or part=="diag" : self.currentFig.pairgrid.map_diag(show_current_axis)
+        allshown = "all" in part
+        if allshown or ("upper" in part): self.currentFig.pairgrid.map_upper(show_current_axis)
+        if allshown or ("lower" in part): 
+            self.currentFig.pairgrid.map_lower(show_current_axis)
+            colnames = dfutils.getColNamesIndex(self._dfref().columns,self.columns)[0]
+            colnamesLength=len(colnames)
+            for i in range(colnamesLength):
+                ax=self.currentFig.pairgrid.axes[:][i][i]
+                if colnamesLength-1>i>0:
+                    ax.set_xlabel("")
+                    ax.set_ylabel("")
+                    ax.xaxis.set_tick_params(which="both", labelbottom=False)
+                    ax.yaxis.set_tick_params(which="both", labelbottom=False)
+                elif i==0:
+                    ax.xaxis.set_tick_params(which="both", labelbottom=False)
+                    ax.set_xlabel("")
+                else:
+                    ax.yaxis.set_tick_params(which="both", labelbottom=False)
+                    ax.set_ylabel("")             
+        if allshown or ("diag" in part): self.currentFig.pairgrid.map_diag(show_current_axis)
+        if allshown or ("cbar" in part): self._addcbar()
 
     ################################################################################################################################
 
